==> libremail-2.3.tar.bz2: libremail/src/trtbordure.c <==
/*
    Fichier trtbordure.c
    Auteur Bernard Chardonneau

    Logiciel libre, droits d'utilisation prciss en franais
    dans le fichier : licence-fr.txt

    Traductions des droits d'utilisation dans les fichiers :
    licence-de.txt , licence-en.txt , licence-es.txt ,
    licence-it.txt , licence-nl.txt , licence-pt.txt ,
    licence-eo.txt , licence-eo-utf.txt

    Droits d'utilisation galement sur la page web :
    http://libremail.tuxfamily.org/voir.php?page=droits


    Bibliothque de fonctions permettant de mmoriser les bordures
    de sections des messages en mode multipart et de vrifier si on
    est positionn sur l'une de ces bordures
*/

#include <stdio.h>
#include <stdlib.h>
#include "buflect.h"
#include "trtbordure.h"



/* rcupre la valeur du champ boundary d'un mail en mode
   multipart et la recopie dans  bordure [nbordures + 1]
   retourne 1 si champ boundary trouv dans la ligne, 0 sinon */

int mem_boundary ()
{
    int i, j;  // compteurs


    // initialisation
    i = 1;

    // chercher le mot  boundary  dans la ligne et sortir s'il n'y est pas
    while (tolower (buf_lect [i]) != 'b' || tolower (buf_lect [i+1]) != 'o')
        if (! buf_lect [++i])
            return (0);

    // se positionner aprs le caractre  =
    while (buf_lect [i++] != '=')
        if (! buf_lect [i])
            return (0);

    // vrifier si l'on peut encore mmoriser une bordure
    if (nbordures >= max_bordures)
    {
        // "Trop de sections dans le mail"
        // "Recompiler avec max_bordures plus grand dans trtbordure.h"
        affiche_err ("DEBORD_SECTIONS-1");
        affiche_err ("DEBORD_SECTIONS-2");

        exit (-1);
    }

    // sauter les blancs aprs le = s'il y en a
    if (buf_lect [i] == ' ')
        i++;

    // sauter galement le  "  s'il y est
    if (buf_lect [i] == '"')
        i++;

    // initialisation
    j = 0;

    // copie de la bordure
    while (buf_lect [i] != '"' && buf_lect [i] != '\0')
        bordure [nbordures][j++] = buf_lect [i++];

    // terminaison de la chaine et prise en compte de la nouvelle bordure
    bordure [nbordures++][j] = '\0';

    // on a trouv le champ boundary
    return (1);
}



/* indique si la ligne courante reprsente une bordure de section */

int surbordure ()
{
    int i;   // compteur


    // si aucune bordure mmorise
    if (! nbordures)
        // "Erreur systme : appel de surbordure() sans bordure mmorise"
        errfatale ("AUCUNE_BORDURE");

    // une bordure commence par 2 caractres -
    if (buf_lect [0] != '-' || buf_lect [1] != '-')
        return (0);

    // initialisation boucle de comparaison
    i = 0;

    // comparer les caractres de la ligne  ceux de la dernire bordure
    while (buf_lect [i+2] == bordure [nbordures-1][i])
    {
        // termin si aucune diffrence trouve en fin de ligne
        if (bordure [nbordures-1][i] == '\0')
            return (1);
        else
            // sinon, passer aux caractres suivants
            i++;
    }

    // diffrence trouve : vrifier si ce sont des -- aprs la bordure
    if (bordure [nbordures-1][i] == '\0' && buf_lect [i+2] == '-')
    {
        // oui : on supprime cette bordure de la liste
        nbordures --;
        return (1);
    }
    else
        // non : bordure non trouve
        return (0);
}

==> libremail-2.4.1.tar.bz2: libremail/src/trtbordure.c <==
/*
    Fichier trtbordure.c
    Auteur Bernard Chardonneau

    Logiciel libre, droits d'utilisation prciss en franais
    dans le fichier : licence-fr.txt

    Traductions des droits d'utilisation dans les fichiers :
    licence-de.txt , licence-en.txt , licence-es.txt ,
    licence-it.txt , licence-nl.txt , licence-pt.txt ,
    licence-eo.txt , licence-eo-utf.txt

    Droits d'utilisation galement sur la page web :
    http://libremail.tuxfamily.org/voir.php?page=droits


    Bibliothque de fonctions permettant de mmoriser les bordures
    de sections des messages en mode multipart et de vrifier si on
    est positionn sur l'une de ces bordures
*/

#include <stdio.h>
#include <stdlib.h>
#include "buflect.h"
#include "trtbordure.h"



/* rcupre la valeur du champ boundary d'un mail en mode
   multipart et la recopie dans  bordure [nbordures + 1]
   retourne 1 si champ boundary trouv dans la ligne, 0 sinon */

int mem_boundary ()
{
    int i, j;  // compteurs


    // initialisation
    i = 1;

    // chercher le mot  boundary  dans la ligne et sortir s'il n'y est pas
    while (tolower (buf_lect [i]) != 'b' || tolower (buf_lect [i+1]) != 'o')
        if (! buf_lect [++i])
            return (0);

    // se positionner aprs le caractre  =
    while (buf_lect [i++] != '=')
        if (! buf_lect [i])
            return (0);

    // vrifier si l'on peut encore mmoriser une bordure
    if (nbordures >= max_bordures)
    {
        // "Trop de sections dans le mail"
        // "Recompiler avec max_bordures plus grand dans trtbordure.h"
        affiche_err ("DEBORD_SECTIONS-1");
        affiche_err ("DEBORD_SECTIONS-2");

        exit (-1);
    }

    // sauter les blancs aprs le = s'il y en a
    if (buf_lect [i] == ' ')
        i++;

    // sauter galement le  "  s'il y est
    if (buf_lect [i] == '"')
        i++;

    // initialisation
    j = 0;

    // copie de la bordure
    while (buf_lect [i] != '"' && buf_lect [i] != '\0')
        bordure [nbordures][j++] = buf_lect [i++];

    // terminaison de la chaine et prise en compte de la nouvelle bordure
    bordure [nbordures++][j] = '\0';

    // on a trouv le champ boundary
    return (1);
}



/* indique si la ligne courante reprsente une bordure de section */

int surbordure ()
{
    int i;   // compteur


    // si aucune bordure mmorise
    if (! nbordures)
        // "Erreur systme : appel de surbordure() sans bordure mmorise"
        errfatale ("AUCUNE_BORDURE");

    // une bordure commence par 2 caractres -
    if (buf_lect [0] != '-' || buf_lect [1] != '-')
        return (0);

    // initialisation boucle de comparaison
    i = 0;

    // comparer les caractres de la ligne  ceux de la dernire bordure
    while (buf_lect [i+2] == bordure [nbordures-1][i])
    {
        // termin si aucune diffrence trouve en fin de ligne
        if (bordure [nbordures-1][i] == '\0')
            return (1);
        else
            // sinon, passer aux caractres suivants
            i++;
    }

    // diffrence trouve

    // si on est arriv  la fin de la bordure mmorise
    if (bordure [nbordures-1][i] == '\0')
    {
        // si dans la ligne, on a  des -- aprs la bordure
        if (buf_lect [i+2] == '-')
        {
            // on supprime cette bordure de la liste (fin de section)
            nbordures --;
            return (1);
        }
        // sinon, si dans la ligne la bordure est suivie d'un espace
        else if (buf_lect [i+2] == ' ')
            // c'est vraiement vicieux, mais on accepte la bordure quand mme
            return (1);
        // sinon
        else
            // on n'a pas trouv la bordure
            return (0);
    }
    // sinon
    else
        // bordure non trouve
        return (0);
}
